@@ -25,11 +25,31 @@ class ProxyQuery(Plugins):
                 plugin.report_fail()
                 continue
 
-    def find_proxies(self, limit: int = -1) -> Iterator[Proxy]:
+    @GenLimiter
+    def find_proxies(self, test: bool = True) -> Iterator[Proxy]:
         """Uses all plugins to search for proxies"""
-        return self.exec_iter_plugin("find", True, limit=limit)
+        proxies = self.exec_iter_plugin("find", True)
 
-    def find_filter(self, limit: int = -1, country: str = None, ping: int = None,
-                    min_anon_level: int = 0) -> Iterator[Proxy]:
+        if test:
+            proxies = self.test_proxies(proxies)
+
+        return proxies
+
+
+    @GenLimiter
+    def find_filter(self, country: str = None, ping: int = None,
+                    min_anon_level: int = 0, test: bool = True) -> Iterator[Proxy]:
         """Uses all plugins to finds proxies that meet certain values"""
-        return self.exec_iter_plugin("find_filter", True, country, ping, min_anon_level, limit=limit)
+        proxies = self.exec_iter_plugin("find_filter", True, country, ping, min_anon_level)
+
+        if test:
+            proxies = self.test_proxies(proxies)
+
+        return proxies
+
+
+    def test_proxies(self, proxies: Iterator[Proxy]) -> Iterator[Proxy]:
+        """Takes a iterator of Proxy and returns a generator that skips over every plugin that failed the test"""
+        for proxy in proxies:
+            if proxy.test():
+                yield proxy
